System.register(['./generated-empty.js'], (function () {
	'use strict';
	return {
		setters: [null],
		execute: (function () {

			console.log('main2');
			const unused = 2;

		})
	};
}));
